@@ -86,7 +86,7 @@
 #define KPACKAGE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPACKAGE_NO_DEPRECATED
-#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KPACKAGE_NO_DEPRECATED_WARNINGS
 #  define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPACKAGE_DEPRECATED_WARNINGS_SINCE KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KPACKAGE_DEPRECATED_VERSION_5(minor, text)      KPACKAGE_DEPRECATED_VERSION_5_##minor(text)
 #define KPACKAGE_DEPRECATED_VERSION(major, minor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KPACKAGE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KPACKAGE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KPACKAGE_DEPRECATED_VERSION(major, minor, text)
+#  define KPACKAGE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPACKAGE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KPACKAGE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KPACKAGE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KPACKAGE_EXPORT_H */
